{% extends "base.html" %}
{% load smart_if %}

{% block meta_title %}{{secteur.label}}{% endblock %}

{% block document %}

<div id="title" class="grid_12 grid">
{% block title %}<h3>{{secteur.label}}</h3>{% endblock %}
</div>

{% block content %}
<div id="content">
    <div class="grid_8 grid">



        <h4>Organisations dans le secteur d'activité "{{secteur.label}}"" </h4>
            <ul class="org_list">
                {% for item in secteur.organization_set.all %}
                <li><a href="{{item.get_absolute_url}}">{{ item.title }}</a>
                    </li>
                {% endfor %}
            </ul>
        <br/>


    </div>


    <div id="grid-right" class="grid_4 grid">


    </div>


</div>
{% endblock %}
{% endblock %}


{% block footer%}
<a href="{{D2RQ_ROOT}}page/role/{{object.slug}}/">
    <img border="0" align="left" src="{{STATIC_URL}}img/semweb.png"></a>
    <br/>
{% endblock %}

