{% extends "base.html" %}{% load i18n %}{% csrf_token %}
{% block title %}{% trans "Add Event" %}{% endblock %}
{% block document %}
    <h3>{% trans "Add Event" %}</h3>
    {{ event_form.non_field_errors }}
    {{ recurring_form.non_field_errors }}
    {% if event_form.errors or recurrence_form.errors %}
    <p>{% trans "Please fix any errors." %}</p>
    {% endif %}
    <form method="post" action="">
    <table>
        <tfoot>
            <tr>
                <td colspan="2"><input type="submit" value="{% trans "Submit" %}" /></td>
            </tr>
        </tfoot>
        <tbody>
        {% include "event_form_part.html" %}
        {% include "recurring_form_part.html" %}
        </tbody>
    </table>
    </form>

{% endblock %}
